| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Database.Bolty.Connection
Description
Internal module. Not part of the public API.
Synopsis
- queryIO :: HasCallStack => Connection -> Text -> IO (Vector Record)
- queryPIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO (Vector Record)
- queryIO' :: HasCallStack => Connection -> Text -> IO SuccessPull
- queryPIO' :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO SuccessPull
- queryWithFieldsIO :: HasCallStack => Connection -> Text -> IO (Vector Text, Vector Record)
- queryPWithFieldsIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO (Vector Text, Vector Record)
- queryPMetaIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO (Vector Text, Vector Record, QueryMeta)
- requestResponseRunIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO SuccessRun
- requestResponsePullIO :: HasCallStack => Connection -> IO SuccessPull
Documentation
queryIO :: HasCallStack => Connection -> Text -> IO (Vector Record) Source #
Run a query, return only records.
queryPIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO (Vector Record) Source #
Run a parameterized query, return only records.
queryIO' :: HasCallStack => Connection -> Text -> IO SuccessPull Source #
Run a query, return full response.
queryPIO' :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO SuccessPull Source #
Run a parameterized query, return full response.
queryWithFieldsIO :: HasCallStack => Connection -> Text -> IO (Vector Text, Vector Record) Source #
Run a query, returning column names alongside records.
queryPWithFieldsIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO (Vector Text, Vector Record) Source #
Run a parameterized query, returning column names alongside records.
queryPMetaIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO (Vector Text, Vector Record, QueryMeta) Source #
Run a parameterized query, returning field names, records, and metadata.
requestResponseRunIO :: HasCallStack => Connection -> Text -> HashMap Text Ps -> IO SuccessRun Source #
Send RUN and receive the run response.
requestResponsePullIO :: HasCallStack => Connection -> IO SuccessPull Source #
Pull all records from an in-progress query.