| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Database.Bolty.Notification
Description
Server notification types (warnings, deprecations, performance hints).
Synopsis
- data Notification = Notification {}
- data Severity
- data Position = Position {}
- parseNotifications :: Maybe Ps -> Vector Notification
Documentation
data Notification Source #
A notification emitted by the server during query execution. Notifications include warnings about performance (cartesian products, missing indexes), deprecation notices, and hints.
Constructors
| Notification | |
Fields
| |
Instances
| Show Notification Source # | |
Defined in Database.Bolty.Notification Methods showsPrec :: Int -> Notification -> ShowS # show :: Notification -> String # showList :: [Notification] -> ShowS # | |
| Eq Notification Source # | |
Defined in Database.Bolty.Notification | |
Severity level of a notification.
Constructors
| SevWarning | |
| SevInformation | |
| SevUnknown !Text |
parseNotifications :: Maybe Ps -> Vector Notification Source #
Parse the raw notifications field from PULL SUCCESS metadata.
Returns an empty vector if the field is Nothing or not a list.